# flake8: noqa

"""
    OFDB API

    OFDB API  # noqa: E501

    The version of the OpenAPI document: 2.1.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.32.1"

# import ApiClient
from fds.sdk.OFDB.api_client import ApiClient

# import Configuration
from fds.sdk.OFDB.configuration import Configuration

# import exceptions
from fds.sdk.OFDB.exceptions import OpenApiException
from fds.sdk.OFDB.exceptions import ApiAttributeError
from fds.sdk.OFDB.exceptions import ApiTypeError
from fds.sdk.OFDB.exceptions import ApiValueError
from fds.sdk.OFDB.exceptions import ApiKeyError
from fds.sdk.OFDB.exceptions import ApiException
